/*
############################################################################
# This program is used to test the basic functions of the SD file system.
# It implements simple versions of the cat, rm, ls, echo, cd, pwd, mkdir and
# rmdir commands plus the <, > and >> file redirection operators.
# The program starts up the file driver and then prompts for a command.
#
# Written by Dave Hein
# Copyright (c) 2011, 2012 Parallax, Inc.
# MIT Licensed
############################################################################
*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <cog.h>
#include <ctype.h>
#include <propeller.h>
#include <unistd.h>
#include <sys/stat.h>
#include <dirent.h>
#include <sys/sd.h>

extern FILE *stdinfile;
extern FILE *stdoutfile;


#undef  SPINNERET_CARD
#undef  PROP_BOE
#undef  C3_CARD
#undef  PARALLEL_SPI

#ifdef CALL_MOUNT
void manual_mount()
{
    printf("Load and mount SD: ");
    _SD_Params* mountParams = (_SD_Params*)-1;

// Important: This code assumes you're using a C3 card.
// If you're using different hardware, make sure you
// change the following initialization to match your card!

#ifdef SPINNERET_CARD
    static _SD_Params params =
    {
        AttachmentType: _SDA_SingleSPI,
        pins:
        {
            SingleSPI:
            {
                MISO: 16,   // The pin attached to the SD card's MISO or DO output
                CLK:  21,   // The pin attached to the SD card's CLK or SCLK input
                MOSI: 20,   // The pin attached to the SD card's MOSI or DI input
                CS:   19    // The pin attached to the SD card's CS input
            }
        }
    };
    mountParams = &params;
#endif

#ifdef PROP_BOE /* Board of Education */
    static _SD_Params params =
    {
        AttachmentType: _SDA_SingleSPI,
        pins:
        {
            SingleSPI:
            {
                MISO: 22,   // The pin attached to the SD card's MISO or DO output
                CLK:  23,   // The pin attached to the SD card's CLK or SCLK input
                MOSI: 24,   // The pin attached to the SD card's MOSI or DI input
                CS:   25    // The pin attached to the SD card's CS input
            }
        }
    };
    mountParams = &params;
#endif

#ifdef C3_CARD
    static _SD_Params params =
    {
        AttachmentType: _SDA_SerialDeMUX,
        pins:
        {
            SerialDeMUX:
            {
                MISO: 10,    // The pin attached to the SD card's MISO or DO output
                CLK:  11,    // The pin attached to the SD card's CLK or SCLK input
                MOSI: 9,     // The pin attached to the SD card's MOSI or DI input
                CLR:  25,    // The pin attached to the counter's reset/clear pin
                INC:  8,     // The pin attached to the counter's clock/count pin
                ADDR: 5,     // The SD card's demux address (the counter's count)
            }
        }
    };
    mountParams = &params;
#endif

#ifdef PARALLEL_SPI /* This is a hypothetical example - modify to suit your needs */
    static _SD_Params params =
    {
        AttachmentType: _SDA_ParallelDeMUX,
        pins:
        {
            ParallelDeMUX:
            {
                MISO: 4,    // The pin attached to the SD card's MISO or DO output
                CLK:  5,    // The pin attached to the SD card's CLK or SCLK input
                MOSI: 6,    // The pin attached to the SD card's MOSI or DI input
                CS:   0,    // The pin attached to the counter's reset/clear pin
                START: 2,   // The start bit of the pin mask to set when selecting the SD card's deMUX address
                WIDTH: 3,   // The width of the pin mask for all pins attached to the deMUX address
        ADDR: 5     // The value to write to the select field when selecting the SD card's deMUX address
            }
        }
    };
    mountParams = &params;
#endif

#if defined(__PROPELLER_XMMC__) && defined(SD_IS_USING_SD_CACHE_DRIVER)
    // Pass NULL as the params. In this case, we'll use the SD Cache driver.
    // Beware: This only works if you're running your program
    // cached off of the SD card (i.e. propeller-load -z).
    mountParams = 0;
#endif

    if (mountParams == (_SD_Params*)-1)
    {
        printf("You must specify the SD paramters in the filetest.c\n");
        exit(1);
    }

    uint32_t mountErr = dfs_mount(mountParams);
    if (mountErr)
    {
        printf("Mount error: %d\n", mountErr);
        exit(1);
    }

    printf("done.\n\n");
}
#endif

/*
+--------------------------------------------------------------------
|  TERMS OF USE: MIT License
+--------------------------------------------------------------------
Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files
(the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge,
publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+------------------------------------------------------------------
*/

